
/*
xpvox copyright (c) 2005 Jan Panteltje

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/



#include "forms.h"
#include "xpvox.h"

extern FD_xpvox *fdui;

int save_setting(char *type, char *string)
{
char pathfilename[READSIZE];
FILE *setting_file;

/* combine with home directory */
sprintf(pathfilename, "%s/.xpvox/setup/%s", home_dir, type);
setting_file = fopen(pathfilename, "w");
if(! setting_file)
	{
	fl_show_alert("Cannot open file for write:", pathfilename, "", 0);
	if(debug_flag)
		{
		fprintf(stderr, "\nCannot open setting file %s for write\n",\
		pathfilename);
		}
	return(0);
	}

fprintf(setting_file, "%s", string);
fclose(setting_file);
return(1);	
}/* end function save_setting */


char *load_setting(char *type)
{
int a;
char temp[4096];
char pathfilename[READSIZE];
FILE *setting_file;

/* combine with home directory */
sprintf(pathfilename, "%s/.xpvox/setup/%s", home_dir, type);

setting_file = fopen(pathfilename, "r");
if(! setting_file)
	{
/*
	fl_show_alert(\
	"Cannot open file for read:", pathfilename, "using defaults", 0);
*/

	if(debug_flag)
		{
		fprintf(stderr, "\nCannot open setting file %s for read\n",\
		pathfilename);
		}

	return 0;
	}

a = readline(setting_file, temp);/* closes file if EOF */	
if(a != EOF) fclose(setting_file);

return( (char *) strsave(temp) );
}/* end function load_setting */


#ifdef VARIABLE_FONTSIZES
int save_fontsizes()
{
char temp[READSIZE];
//sprintf(temp, "%d", main_form_fontsize);

return 1;
);

if(! save_setting("fontsizes", temp) ) return(0);

return 1;
}/* end function save_fontsizes */


int load_fontsizes()
{
char *data_read;
 
data_read = (char *) load_setting("fontsizes");
if(! data_read) return(0);

//sscanf(data_read, "%d", &main_form_fontsize);

free(data_read);

//fl_set_browser_fontsize(fdui -> xpvox, main_form_fontsize);

return 1;
}/* end function load_fontsizes */

#endif // VARIABLE_FONTSIZES


int set_audio_output_device(int nr)
{
char text[80];
int color = 0; // -Wall

if(debug_flag)
	{
	printf("set_audio_output_device(): arg nr=%d\n", nr);
	}

switch(nr)
	{
	case 0:
		color = FL_COL1;	
		break;
	case 1:
		color = FL_ORCHID;
		break;
	case 2:
		color = FL_RED;
		break;
	case 3:
		color = FL_DARKORANGE;
		break;
	} /* end switch mode */

sprintf(text, "/dev/dsp%d", nr);

fl_set_object_label(fdui -> audio_output_device_select_button, text);
fl_set_object_color(fdui -> audio_output_device_select_button, color, color);

if(audio_output_device) free(audio_output_device);
audio_output_device = strsave(text);
if(! audio_output_device)
	{
	fprintf(stderr, "set_audio_output_device(): could not allocate space for audio_output_device\n");

	return 0;
	}

if(debug_flag)
	{
	fprintf(stderr, "audio_output_device=%s\n", audio_output_device);
	}

return 1;
} /* end function set_audio_output_device */


int set_audio_input_device(int nr)
{
char text[80];
int color = 0; // -Wall

if(debug_flag)
	{
	printf("set_audio_input_device(): arg nr=%d\n", nr);
	}

switch(nr)
	{
	case 0:
		color = FL_COL1;	
		break;
	case 1:
		color = FL_ORCHID;
		break;
	case 2:
		color = FL_RED;
		break;
	case 3:
		color = FL_DARKORANGE;
		break;
	} /* end switch mode */

sprintf(text, "/dev/dsp%d", nr);

fl_set_object_label(fdui -> audio_input_device_select_button, text);
fl_set_object_color(fdui -> audio_input_device_select_button, color, color);

if(audio_input_device) free(audio_input_device);
audio_input_device = strsave(text);
if(! audio_input_device)
	{
	fprintf(stderr, "set_audio_input_device(): could not allocate space for audio_input_device\n");

	return 0;
	}

if(debug_flag)
	{
	fprintf(stderr, "audio_input_device=%s\n", audio_input_device);
	}

return 1;
} /* end function set_audio_input_device */


int save_audio_settings()
{
char temp[1024];

if(debug_flag)
	{
	fprintf(stderr, "save_audio_settings(): arg none\n");
	}

sprintf(temp, "%d %d %d %d %d %d %d %d %d %d %d %d %d %d %d",\
play_lead_in_flag,\
play_lead_out_flag,\
audio_input_device_number,\
audio_output_device_number,\
beacon_period_time,\
alarm_hour,\
alarm_minute,\
auto_transmit_flag,\
play_one_per_day_flag,\
auto_play_sequence_number,\
show_sounds_without_path_flag,\
log_flag,\
off_time_10x_flag,\
agc_flag,\
use_xpequ_flag);

save_setting("audio_settings", temp);

return 1;
} /* end function save_audio_settings */


int load_audio_settings()
{
char *ptr;
char temp[80];

if(debug_flag)
	{
	fprintf(stderr, "load_audio_settings(): arg none\n");
	}

ptr = (char *) load_setting("audio_settings");
if( ! ptr)
	{
	/* report about usings defaults in load settings() */
	}
else
	{
	sscanf(ptr, "%d %d %d %d %d %d %d %d %d %d %d %d %d %d %d",\
	&play_lead_in_flag,\
	&play_lead_out_flag,\
	&audio_input_device_number,\
	&audio_output_device_number,\
	&beacon_period_time,\
	&alarm_hour,\
	&alarm_minute,\
	&auto_transmit_flag,\
	&play_one_per_day_flag,\
	&auto_play_sequence_number,\
	&show_sounds_without_path_flag,\
	&log_flag,\
	&off_time_10x_flag,\
	&agc_flag,\
	&use_xpequ_flag);
	}

if(debug_flag)
	{
	fprintf(stderr, "play_lead_in_flag=%d play_lead_out_flag=%d\n", play_lead_in_flag, play_lead_out_flag);
	}

fl_set_button(fdui -> in_sound_button, play_lead_in_flag);
fl_set_button(fdui -> out_sound_button, play_lead_out_flag);

set_audio_input_device(audio_input_device_number);

set_audio_output_device(audio_output_device_number);

sprintf(temp, "%d", beacon_period_time);
fl_set_input(fdui -> beacon_period_time_input_field, temp);

sprintf(temp, "%02d:%02d", alarm_hour, alarm_minute);
fl_set_input(fdui -> timed_play_input_field, temp);

fl_set_button(fdui -> timed_play_button, auto_transmit_flag);

fl_set_button(fdui -> play_one_per_day_button, play_one_per_day_flag);

if(! play_one_per_day_flag) auto_play_sequence_number = 1;

sprintf(temp, "%d", auto_play_sequence_number);
fl_set_input(fdui -> play_one_per_day_next_input_field, temp);

fl_set_button(fdui -> show_sounds_without_path_button, show_sounds_without_path_flag);

fl_set_button(fdui -> log_button, log_flag);

fl_set_button(fdui ->  off_time_x10_button, off_time_10x_flag);
set_off_slider_bounds();

fl_set_button(fdui -> agc_button, agc_flag);

fl_set_button(fdui -> use_xpequ_button, use_xpequ_flag);

return 1;
} /* end function load_audio_settings */


void set_off_slider_bounds()
{
if(debug_flag)
	{
	fprintf(stderr, "set_off_slider_bounds(): arg none, using off_time_10x_flag=%d\n", off_time_10x_flag);
	}

if(off_time_10x_flag)
	{
	fl_set_slider_bounds(fdui -> off_time_slider, 40000, 1000);
	}
else
	{
	fl_set_slider_bounds(fdui -> off_time_slider, 4000, 100);
	}

} /* end function set_off_slider_bounds */


